@@ -33,6 +33,27 @@ get.basis.set = function(amat) {
     
   ret = ret[!sapply(ret, is.null)]
   
+  if(length(ret) == 0) 
+    
+    stop("All endogenous variables are conditionally dependent.\nTests of directed separation not possible!", call. = FALSE)
+    
+  # Add binding for binomial variables
+  for(i in 1:length(ret)) {
+    
+    if(any(grepl(",", ret[[i]]))) {
+      
+      idx = which(grepl(",", ret[[i]]))
+      
+      for(j in idx) {
+        
+        ret[[i]][j] = paste0("cbind(", ret[[i]][j], ")")
+        
+      }
+      
+    }
+    
+  }
+  
   return(ret)
   
 }
\ No newline at end of file
